@@ -15,9 +15,6 @@ class Data(Iterable):
     task- and electrode-related variables. Under the hood, it consists
     of a list of dictionaries where each dictionary contains all the data
     for one trial.
-
-    Please see the :ref:`example notebooks <working with data>` for more detailed
-    tutorials which demonstrate using the Data object in different types of analysis.
     
     Parameters
     ----------
@@ -91,8 +88,6 @@ class Data(Iterable):
     Data object of 2 trials containing 3 fields
     [{"name": <class 'str'>, "resp": <class 'numpy.ndarray'>, "dataf": <class 'int'>}
     {"name": <class 'str'>, "resp": <class 'numpy.ndarray'>, "dataf": <class 'int'>}]
-
-    
     '''
     def __init__(self, data, strict=False):
         
@@ -101,11 +96,11 @@ class Data(Iterable):
             for k, v in data.items():
                 if not isinstance(v, list):
                     raise TypeError(f'When creating a Data from a dict, each value in the '
-                                     'dict must be a list, but for key "{k}" got type {type(v)}')
+                                    f'dict must be a list, but for key "{k}" got type {type(v)}')
                 lengths.append(len(v))
             if not _all_equal_list(lengths):
                 raise ValueError(f'When creating a Data from a dict, each value in the '
-                                  'dict must be a list of the same length, but got different lengths: {lengths}')
+                                f'dict must be a list of the same length, but got different lengths: {lengths}')
             data = [dict(zip(data, vals)) for vals in zip(*data.values())]
             self._data = data
         elif isinstance(data, list):
@@ -135,7 +130,7 @@ class Data(Iterable):
         if not isinstance(fielddata, list):
             raise TypeError(f'Input data must be a list, but found {type(fielddata)}')
         if len(fielddata) != len(self):
-            raise Exception('Length of field is not equal to length of this Data')
+            raise Exception(f'Length of field ({len(fielddata)}) is not equal to length of this Data ({len(self)})')
         for i in range(len(self.data)):
             self.data[i][fieldname] = fielddata[i]
             
@@ -212,8 +207,6 @@ class Data(Iterable):
             else:
                 return Data([self.data[i] for i in index], strict=False)
         try:
-            # TODO: change this to return a type Data if you do slicing - problem with trying to
-            # print because it says KeyError for self.data[0] for key 0
             return self.data[index]
         except IndexError:
             raise IndexError(f'Index invalid for this data. Tried to index {index} but length is {len(self)}.')
@@ -428,7 +421,7 @@ class Data(Iterable):
     @property
     def mne_info(self):
         '''
-        `mne.Info <https://mne.tools/dev/generated/mne.Info.html>`_ instance
+        mne.Info instance
         which stores measurement information and can be used with mne's visualization
         functions. This is empty by default unless it is manually added or read in
         by a function like `naplib.io.read_bids`.
@@ -442,7 +435,6 @@ class Data(Iterable):
 def concat(data_list, axis=0, copy=True):
     '''
     Concatenate Data objects across either trials or fields.
-
     This performs an inner join on the other dimension, meaning
     non-shared fields will be lost if concatenating over trials,
     and non-shared trials will be lost if concatenating over fields.
@@ -455,14 +447,13 @@ def concat(data_list, axis=0, copy=True):
     
     Parameters
     ----------
-    data : sequence of Data instances
+    data : list or tuple of Data instances
         Sequence containing the different Data objects to concatenate.
     axis : int, defualt=0
         To concantate over trials (default), axis should be 0. To concatenate
         over fields, axis should be 1.
     copy : bool, default=True
         Whether to deep copy each Data object before concatenating.
-
     Returns
     -------
     data_merged : Data instance
@@ -500,9 +491,13 @@ def concat(data_list, axis=0, copy=True):
     [[1, 2], [3, 4, 5]]
     >>> d_concat['meta_data']
     ['meta1', 'meta2']
-
     '''
-
+    if not isinstance(data_list, (list, tuple)):
+        raise TypeError(f'data_list must be a list or tuple but got {type(data_list)}')
+        
+    if len(data_list) == 0:
+        raise ValueError('need at least one Data object to concatenate')
+        
     for out in data_list:
         if not isinstance(out, Data):
             raise TypeError(f'All inputs to data_list must be a Data instance but found {type(out)}')
@@ -511,13 +506,10 @@ def concat(data_list, axis=0, copy=True):
         return data_list[0]
     
     if axis == 0:
-        field_set = OrderedDict({k: None for k in data_list[0].fields})
+        field_set = set(data_list[0].fields)
         for data in data_list[1:]:
-            subset = set(field_set.keys()).intersection(set(data.fields))
-            for k in field_set:
-                if k not in subset:
-                    field_set.pop(k)
-        field_set = list(field_set.keys())
+            field_set = field_set.intersection(set(data.fields))
+        field_set = [ff for ff in data_list[0].fields if ff in field_set]
         
         if copy:
             data_merged = deepcopy(data_list[0][field_set])
@@ -551,7 +543,6 @@ def concat(data_list, axis=0, copy=True):
         raise ValueError(f'axis must be 0 or 1 but got {axis}')
         
     return data_merged
-
     
 def join_fields(data_list, fieldname='resp', axis=-1, return_as_data=False):
     '''
